/**********************************************************************************
 * Project: TMVA - a Root-integrated toolkit for multivariate data analysis       *
 * Package: TMVA                                                                  *
 * Class  : TMVA_AsciiConverter                                                   *
 *                                                                                *
 * Description:                                                                   *
 *      Convert ascii file into TTree object                                      *
 *      (TMVA_AsciiConverter does not own this TTree object)                      *
 *                                                                                *
 *      Supported data types are:                                                 *
 *      Float_t  Double_t  Int_t TString                                          *
 *                                                                                *
 *      Ascii file format:                                                        *
 *      Var1/D:Var2/F:Var3/I ...                                                  *
 *      1.3    3.55 3.2 5    ...                                                  *
 *      ...                                                                       *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: TMVA_AsciiConverter.h,v 1.3 2006/03/14 20:59:51 kaivoss Exp $       
 **********************************************************************************/

#ifndef __TMVA_AsciiConverter_h__
#define __TMVA_AsciiConverter_h__

#include <fstream>
#include "TTree.h"
#include "TObject.h"
#include "TObjString.h"
#include "TString.h"
#include "TArrayF.h"
#include "TArrayD.h"
#include "TArrayI.h"

class TMVA_AsciiConverter : public TObject {
  
public:

  TMVA_AsciiConverter ( void );
  TMVA_AsciiConverter (TString infile, TTree* theTree );
  ~TMVA_AsciiConverter( void );
  
  void        ParseFormatLine( void );
  void        CreateBranches ( void );
  void        FillFromFile   ( void );
  
  TTree*      GetTree        ( void ) const { return m_tree;       }
  Int_t       GetNBranch     ( void ) const { return m_nbranch;    }
  TList*      GetFormatList  ( void ) const { return m_FormatList; }
  TList*      GetLabelList   ( void ) const { return m_LabelList;  }
  Int_t       GetNumInt      ( void ) const { return m_int_cnt;    }
  Int_t       GetNumDbl      ( void ) const { return m_dbl_cnt;    }
  Int_t       GetNumFloat    ( void ) const { return m_float_cnt;  }
  Bool_t      GetFileStatus  ( void ) const { return m_FileStatus; }

protected:
  void        SetInputFile( TString infile );

  Bool_t      IsInteger( TString* branchformat );
  Bool_t      IsDouble ( TString* branchformat );
  Bool_t      IsFloat  ( TString* branchformat );
  Bool_t      IsString ( TString* branchformat );


  Double_t*   m_Data_dbl; 
  Float_t*    m_Data_float;
  Int_t*      m_Data_int; 
  TObjString* m_Data_str[1000]; // pointer to TObjString branch
  
  Int_t       m_dbl_cnt; 
  Int_t       m_float_cnt;
  Int_t       m_int_cnt; 
  Int_t       m_char_cnt; 
  Int_t       m_dbl_array_cnt;
  Int_t       m_float_array_cnt;
  Int_t       m_int_array_cnt; 

  TList*      m_FormatList; 
  TList*      m_LabelList;  

  ifstream    m_Infile; 
  Int_t       m_nbranch; 
  Bool_t      m_FileStatus; 
  TTree*      m_tree;
  
  Bool_t      m_ParseFormatLineDone;
  Bool_t      m_CreateBranchesDone; 
  Bool_t      m_FillFromFileDone; 

 
  ClassDef(TMVA_AsciiConverter,0) // Ascii tree library    
};

#endif
