/**********************************************************************************
 * Project: TMVA - a Root-integrated toolkit for multivariate data analysis       *
 * Package: TMVA                                                                  *
 * Class  : TMVA_DecisionTree                                                     *
 *                                                                                *
 * Description:                                                                   *
 *      Implementation of a Decision Tree                                         *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Andreas Hoecker <Andreas.Hocker@cern.ch> - CERN, Switzerland              *
 *      Xavier Prudent  <prudent@lapp.in2p3.fr>  - LAPP, France                   *
 *      Helge Voss      <Helge.Voss@cern.ch>     - MPI-KP Heidelberg, Germany     *
 *      Kai Voss        <Kai.Voss@cern.ch>       - U. of Victoria, Canada         *
 *                                                                                *
 * Copyright (c) 2005:                                                            *
 *      CERN, Switzerland,                                                        * 
 *      U. of Victoria, Canada,                                                   * 
 *      MPI-KP Heidelberg, Germany,                                               * 
 *      LAPP, Annecy, France                                                      *
 *                                                                                *
 * Redistribution and use in source and binary forms, with or without             *
 * modification, are permitted according to the terms listed in LICENSE           *
 * (http://mva.sourceforge.net/license.txt)                                       *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: TMVA_DecisionTree.h,v 1.2 2006/03/14 00:00:00 helgevoss Exp $    
 **********************************************************************************/

#ifndef TMVA_DecisionTree_H
#define TMVA_DecisionTree_H

#include "TMVA_BinaryTree.h"
#include "TMVA_DecisionTreeNode.h"
#include "TMVA_BinarySearchTree.h"
#include "TMVA_SeparationBase.h"

using std::vector;

class TMVA_DecisionTree : public TMVA_BinaryTree {
  
 public:

  // the constructur needed for the "reading" of the decision tree from weight files
  TMVA_DecisionTree( void );

  // the constructur needed for constructing the decision tree via training with events
  TMVA_DecisionTree( TMVA_SeparationBase *sepType,Int_t minSize, Double_t mnsep, 
		     Int_t nCuts);
  ~TMVA_DecisionTree( void );
  
  void BuildTree( vector<TMVA_Event*> & eventSample, 
		  TMVA_DecisionTreeNode *node = NULL );

  Double_t TrainNode( vector<TMVA_Event*> & eventSample,  TMVA_DecisionTreeNode *node );

  // returns: 1 = Signal (right),  -1 = Bkg (left)
  Int_t CheckEvent( TMVA_Event* ); 

 private:

  // calculate the Purity out of the number of sig and bkg events collected
  // from individual samples.

  Double_t SamplePurity(vector<TMVA_Event*> eventSample);
  
  Int_t     m_nvars;
  Int_t     m_nCuts; // ! m_nCuts * m_nCuts  different cuts are scanned.
  TMVA_SeparationBase *m_sepType;

/*   Double_t  m_SoverSBUpperThreshold; */
/*   Double_t  m_SoverSBLowerThreshold; */
  Double_t  m_minSize;
  Double_t  m_minSepGain;

  Bool_t    m_useSearchTree;
};

#endif 
