/**********************************************************************************
 * Project: TMVA - a Root-integrated toolkit for multivariate data analysis       *
 * Package: TMVA                                                                  *
 * Class  : TMVA_DecisionTreeNode                                                 *
 *                                                                                *
 * Description:                                                                   *
 *      Node for the Decision Tree                                                *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Andreas Hoecker <Andreas.Hocker@cern.ch> - CERN, Switzerland              *
 *      Xavier Prudent  <prudent@lapp.in2p3.fr>  - LAPP, France                   *
 *      Helge Voss      <Helge.Voss@cern.ch>     - MPI-KP Heidelberg, Germany     *
 *      Kai Voss        <Kai.Voss@cern.ch>       - U. of Victoria, Canada         *
 *                                                                                *
 * Copyright (c) 2005:                                                            *
 *      CERN, Switzerland,                                                        * 
 *      U. of Victoria, Canada,                                                   * 
 *      MPI-KP Heidelberg, Germany,                                               * 
 *      LAPP, Annecy, France                                                      *
 *                                                                                *
 * Redistribution and use in source and binary forms, with or without             *
 * modification, are permitted according to the terms listed in LICENSE           *
 * (http://mva.sourceforge.net/license.txt)                                       *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: TMVA_DecisionTreeNode.h,v 1.2 2006/03/14 00:00:00 helgevoss Exp $    
 **********************************************************************************/

#ifndef TMVA_DecisionTreeNode_H
#define TMVA_DecisionTreeNode_H

#include "TMVA_Node.h"

using std::string;

class TMVA_DecisionTreeNode: public TMVA_Node {

 public:

  TMVA_DecisionTreeNode (TMVA_Event* e =NULL);

  TMVA_DecisionTreeNode (TMVA_Node* p); 

  ~TMVA_DecisionTreeNode(){};

  virtual bool goesRight( const TMVA_Event* ) const;
  virtual bool goesLeft ( const TMVA_Event* ) const;

  void  cutMin ( Double_t c ) { m_cutMin  = c; }
  void  cutMax ( Double_t c ) { m_cutMax  = c; }
  void  cutType( Bool_t t   ) { m_cutType = t; }

  Double_t  cutMin ( void ) const { return m_cutMin;  }
  Double_t  cutMax ( void ) const { return m_cutMax;  }

  // kTRUE: Cuts select signal, kFALSE: Cuts select bkg
  Bool_t    cutType( void ) const { return m_cutType; }

  // 1 signal node, -1 bkg leave, 0 intermediate Node
  void  nodeType( Int_t t ) { m_nodeType = t;} 
  Int_t nodeType( void ) const { return m_nodeType; }

  void     SoverSB( Double_t ssb ){ m_SoverSB =ssb ; }
  Double_t SoverSB( void ) const  { return m_SoverSB; }

  void     separationIndex( Double_t sep ){ m_SeparationIndex =sep ; }
  Double_t separationIndex( void ) const  { return m_SeparationIndex; }

  void     separationGain( Double_t sep ){ m_SeparationGain =sep ; }
  Double_t separationGain( void ) const  { return m_SeparationGain; }

  void     nEvents( Double_t nev ){ m_nEvents =nev ; }
  Double_t nEvents( void ) const  { return m_nEvents; }

  virtual void        printRec( ostream&  os, const int depth=0, const string pos="root" ) const;
  virtual TMVA_NodeID readRec ( ifstream& is, TMVA_NodeID nodeID, TMVA_Node* parent=NULL );
  
 private:
  
  Double_t m_cutMin;
  Double_t m_cutMax;
  Bool_t   m_cutType;
  
  Double_t m_SoverSB;
  Double_t m_SeparationIndex;
  Double_t m_SeparationGain;
  Double_t m_nEvents;
  Int_t    m_nodeType;
  

};



#endif 
