/**********************************************************************************
 * Project: TMVA - a Root-integrated toolkit for multivariate data analysis       *
 * Package: TMVA                                                                  *
 * Class  : TMVA_Event                                                            *
 *                                                                                *
 * Description:                                                                   *
 *       Event: variables of an event as used for the Binary Tree                 *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Andreas Hoecker <Andreas.Hocker@cern.ch> - CERN, Switzerland              *
 *      Xavier Prudent  <prudent@lapp.in2p3.fr>  - LAPP, France                   *
 *      Helge Voss      <Helge.Voss@cern.ch>     - MPI-KP Heidelberg, Germany     *
 *      Kai Voss        <Kai.Voss@cern.ch>       - U. of Victoria, Canada         *
 *                                                                                *
 * Copyright (c) 2005:                                                            *
 *      CERN, Switzerland,                                                        * 
 *      U. of Victoria, Canada,                                                   * 
 *      MPI-KP Heidelberg, Germany                                                * 
 *      LAPP, Annecy, France                                                      *
 *                                                                                *
 * Redistribution and use in source and binary forms, with or without             *
 * modification, are permitted according to the terms listed in LICENSE           *
 * (http://mva.sourceforge.net/license.txt)                                       *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: TMVA_Event.h,v 1.1 2006/02/19 23:20:49 helgevoss Exp $    
 **********************************************************************************/

#ifndef TMVA_Event_H
#define TMVA_Event_H

#include <iostream>
#include <fstream>
#include <vector>
#include "Riostream.h"
#include "TVector.h"
#include "TTree.h"
#include "TString.h"

// an Event coordinate
// simple enough for any event with one weight and 1 to n characterising variables,
// but could also be inherited from extened if needed 

class TMVA_Event {

  friend ostream& operator << (ostream& os, const TMVA_Event& event);
  friend ostream& operator << (ostream& os, const TMVA_Event* event);

 public:
    
  TMVA_Event() : m_weight( 1 ), m_type( -1 ) {};
  TMVA_Event( std::vector<Double_t> &v, Double_t w = 1 , Int_t t=-1) 
    : m_var( v ), m_weight( w ), m_type( t ) {};
  TMVA_Event(TTree* tree, Int_t ievt, std::vector<TString>* m_inputVars);

  inline const std::vector<Double_t> &data() const    {return m_var;};
  const Double_t              &data(int i) const;
  inline int size() const {return m_var.size();};
  inline void insert(Double_t v){m_var.push_back(v);};
  inline void weight(Double_t w ){m_weight=w;}
  inline Double_t weight()const {return m_weight;}
  inline Int_t type() const {return m_type;};
  inline Int_t type2() const {return m_type ? m_type : -1 ;};
  inline void type(Int_t t){ m_type=t;};

  void print(ostream& os) const;

  TMVA_Event* read(std::ifstream& is);

 private:

  std::vector<Double_t>  m_var;
  Double_t               m_weight;
  Int_t                  m_type;
};

#endif // TMVA_Event_H

