
/**********************************************************************************
 * Project: TMVA - a Root-integrated toolkit for multivariate data analysis        *
 * Package: TMVA                                                                   *
 * Class  : TMVA_GeneticBase                                                     *
 *                                                                                *
 * Description:                                                                   *
 *    Base definition for genetic algorithm                                      *
 *                                                                                *
 *                                                                                *
 *                                                                                *
 *                                '                                                *
 *                                                                                *
 *                                                                                *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Andreas Hoecker  <Andreas.Hocker@cern.ch> - CERN, Switzerland              *
 *      Xavier Prudent   <prudent@lapp.in2p3.fr>  - LAPP, France                   *
 *      Peter Speckmayer <speckmay@mail.cern.ch>  - CERN, Switzerland              *
 *      Helge Voss       <Helge.Voss@cern.ch>     - MPI-KP Heidelberg, Germany     *
 *      Kai Voss         <Kai.Voss@cern.ch>       - U. of Victoria, Canada         *
 *                                                                                *
 * Copyright (c) 2005:                                                            *
 *      CERN, Switzerland,                                                        * 
 *      U. of Victoria, Canada,                                                   * 
 *      MPI-KP Heidelberg, Germany                                                * 
 *      LAPP, Annecy, France                                                      *
 *                                                                                *
 * Redistribution and use in source and binary forms, with or without             *
 * modification, are permitted according to the terms listed in LICENSE           *
 * (http://mva.sourceforge.net/license.txt)                                       *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: TMVA_GeneticBase.h,v 1.2 2006/04/07 10:35:02 andreas.hoecker Exp $    
 **********************************************************************************/

#ifndef TMVA_GeneticBase_H
#define TMVA_GeneticBase_H
#include <vector>
#include <deque>
#include <map>
#include <string>

#include <stdio.h>
#include <iostream>

#include "TRandom.h"
#include "TH1F.h"

#include "TMVA_GeneticPopulation.h"

typedef std::pair< double, double > LowHigh;

class TMVA_GeneticBase {
    private:
    	// converging?
	int convCounter;
	double convValue;
	
	// spread-control (stepsize)
	std::deque< int > successList;
	double lastResult;
    public:
        TMVA_GeneticPopulation population;

        double spread;  // regulates the spread of the value change at mutation (sigma)
	bool mirror;
        bool sexual;
        bool firstTime;

	TMVA_GeneticBase(){}
        TMVA_GeneticBase( int populationSize, std::vector<LowHigh*> ranges );
	virtual ~TMVA_GeneticBase() {}
        void init();
	virtual bool hasConverged( int steps = 10, double ratio = 0.1 );
	virtual double spreadControl( int steps, int ofSteps, double factor );
        double calc();
        virtual double fitnessFunction( std::vector< double > factors );
        virtual double newFitness( double oldValue, double newValue );
        virtual double calculateFitness( );
        double doRenewFitness( );
        virtual double renewFitness( std::vector< double > factors, std::vector< double > results );
        virtual void evolution();
        void finalize( );
} ;



#endif // TMVA_GeneticBase_H
