/**********************************************************************************
 * Project: TMVA - a Root-integrated toolkit for multivariate data analysis        *
 * Package: TMVA                                                                   *
 * Class  : TMVA_GeneticPopulation                                                     *
 *                                                                                *
 * Description:                                                                   *
 *    Population definition for genetic algorithm                                      *
 *                                                                                *
 *                                                                                *
 *                                                                                *
 *                                '                                                *
 *                                                                                *
 *                                                                                *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Andreas Hoecker  <Andreas.Hocker@cern.ch> - CERN, Switzerland              *
 *      Xavier Prudent   <prudent@lapp.in2p3.fr>  - LAPP, France                   *
 *      Peter Speckmayer <speckmay@mail.cern.ch>  - CERN, Switzerland              *
 *      Helge Voss       <Helge.Voss@cern.ch>     - MPI-KP Heidelberg, Germany     *
 *      Kai Voss         <Kai.Voss@cern.ch>       - U. of Victoria, Canada         *
 *                                                                                *
 * Copyright (c) 2005:                                                            *
 *      CERN, Switzerland,                                                        * 
 *      U. of Victoria, Canada,                                                   * 
 *      MPI-KP Heidelberg, Germany                                                * 
 *      LAPP, Annecy, France                                                      *
 *                                                                                *
 * Redistribution and use in source and binary forms, with or without             *
 * modification, are permitted according to the terms listed in LICENSE           *
 * (http://mva.sourceforge.net/license.txt)                                       *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: TMVA_GeneticPopulation.h,v 1.2 2006/04/07 10:35:02 andreas.hoecker Exp $    
 **********************************************************************************/

#ifndef TMVA_GeneticPopulation_H
#define TMVA_GeneticPopulation_H


#include <string>
#include <vector>
#include <map>
#include "TF1.h"
#include "TH1F.h"

#include "TMVA_GeneticGenes.h"
#include "TMVA_GeneticRange.h"


class TMVA_GeneticPopulation {
    public:
        TRandom *randomGenerator;
        typedef std::pair< double, TMVA_GeneticGenes > entry;
//        typedef pair< double,vector<double> > entry;
//        multimap<double, vector<double>  >* factors;
//        multimap<double, vector<double>  >* newFactors;
        std::multimap<double, TMVA_GeneticGenes  >* genePool;
        std::multimap<double, TMVA_GeneticGenes  >* newGenePool;

        std::vector< TMVA_GeneticRange* > ranges;

        std::multimap<double, TMVA_GeneticGenes >::iterator counter;
        double counterFitness;

        int populationSize;

        TMVA_GeneticPopulation();
        void createPopulation( int size );
        void addPopulation( TMVA_GeneticPopulation *genePool );
        void trimPopulation();
        void giveHint( std::vector< double > hint, double fitness = 0 );
        void makeChildren();
        TMVA_GeneticGenes TMVA_GeneticPopulation::makeSex( TMVA_GeneticGenes male, TMVA_GeneticGenes female );
        void makeMutants( double probability = 30, bool near = false, double spread = 0.1, bool mirror=false  );
        void mutate( double probability = 20, int startIndex = 0, bool near = false, double spread = 0.1, bool mirror=false  );
        void addFactor( double from, double to );
        TMVA_GeneticGenes* getGenes();
        TMVA_GeneticGenes* getGenes( int index );
        void clearResults( );
        void reset();
        bool setFitness( TMVA_GeneticGenes *g, double fitness, bool add = true );
        double getFitness( int index );
        double getFitness( );
        void print( int untilIndex = -1 );
        void print( ostream & out, int utilIndex = -1 );
        TH1F* variableDistribution( int varNumber, int bins, int min, int max  );
        std::vector< double > variableDistribution( int varNumber );

        ~TMVA_GeneticPopulation();
};



#endif // TMVA_GeneticPopulation_H
