/**********************************************************************************
 * Project: TMVA - a Root-integrated toolkit for multivariate data analysis        *
 * Package: TMVA                                                                   *
 * Class  : TMVA_GeneticRange                                                     *
 *                                                                                *
 * Description:                                                                   *
 *    Range definition for genetic algorithm                                      *
 *                                                                                *
 *                                                                                *
 *                                                                                *
 *                                                                                *
 *                                                                                *
 *                                                                                *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Andreas Hoecker  <Andreas.Hocker@cern.ch> - CERN, Switzerland              *
 *      Xavier Prudent   <prudent@lapp.in2p3.fr>  - LAPP, France                   *
 *      Peter Speckmayer <speckmay@mail.cern.ch>  - CERN, Switzerland              *
 *      Helge Voss       <Helge.Voss@cern.ch>     - MPI-KP Heidelberg, Germany     *
 *      Kai Voss         <Kai.Voss@cern.ch>       - U. of Victoria, Canada         *
 *                                                                                *
 * Copyright (c) 2005:                                                            *
 *      CERN, Switzerland,                                                        * 
 *      U. of Victoria, Canada,                                                   * 
 *      MPI-KP Heidelberg, Germany                                                * 
 *      LAPP, Annecy, France                                                      *
 *                                                                                *
 * Redistribution and use in source and binary forms, with or without             *
 * modification, are permitted according to the terms listed in LICENSE           *
 * (http://mva.sourceforge.net/license.txt)                                       *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: TMVA_GeneticRange.h,v 1.2 2006/04/07 10:35:02 andreas.hoecker Exp $    
 **********************************************************************************/

#ifndef TMVA_GeneticRange_H
#define TMVA_GeneticRange_H

#include "TRandom.h"

class TMVA_GeneticRange {
    public:
        double from, to;
        double totalLength;

        TRandom *randomGenerator;

        TMVA_GeneticRange( TRandom *rnd, double f, double t );
        double random( bool near = false, double value=0, double spread=0.1, bool mirror=false );

        ~TMVA_GeneticRange();

     private:
        // maps the values thrown outside of the ]from,to] interval back to the interval
        // the values which leave the range on the from-side, are mapped in to the to-side
        double reMap( double val );
        // same as before, but the values leaving the allowed range, are mirrored into the range.
        double reMapMirror( double val );
};


#endif // TMVA_GeneticRange_H
