/**********************************************************************************
 * Project: TMVA - a Root-integrated toolkit for multivariate data analysis       *
 * Package: TMVA                                                                  *
 * Class  : TMVA_GiniIndex                                                        *
 *                                                                                *
 * Description: Implementation of the GiniIndex as separation criterion           *
 *              Large Gini Indices mean, that the sample is well mixed signal and *
 *              bkg. Small Indices mean, well separated. Hence we want a minimal  *
 *              Gini_left + Gini_right, or a                                      *
 *                MAXIMAl Gini_parent-Gini_left-Gini_right                        * 
 *                                                                                *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Andreas Hoecker <Andreas.Hocker@cern.ch> - CERN, Switzerland              *
 *      Xavier Prudent  <prudent@lapp.in2p3.fr>  - LAPP, France                   *
 *      Helge Voss      <Helge.Voss@cern.ch>     - MPI-KP Heidelberg, Germany     *
 *      Kai Voss        <Kai.Voss@cern.ch>       - U. of Victoria, Canada         *
 *                                                                                *
 * Copyright (c) 2005:                                                            *
 *      CERN, Switzerland,                                                        * 
 *      U. of Victoria, Canada,                                                   * 
 *      Heidelberg U., Germany,                                                   * 
 *      LAPP, Annecy, France                                                      *
 *                                                                                *
 * Redistribution and use in source and binary forms, with or without             *
 * modification, are permitted according to the terms listed in LICENSE           *
 * (http://tmva.sourceforge.net/license.txt)                                      *
 *                                                                                *
 * File and Version Information:                                                  *
 *      $Id: TMVA_GiniIndex.h,v 1.3 2006/03/14 17:05:48 helgevoss Exp $           *
 **********************************************************************************/
#ifndef TMVA_GINIINDEX_H
#define TMVA_GINIINDEX_H

#include "TMVA_SeparationBase.h"

class TMVA_GiniIndex : public TMVA_SeparationBase {
 public:
  TMVA_GiniIndex() {m_name="Gini";};
  virtual ~TMVA_GiniIndex(){};

 protected:
  virtual Double_t  separationIndex( const Double_t &s, const Double_t &b );
  
};

#endif // TMVA_GINIINDEX_H

