/**********************************************************************************
 * Project: TMVA - a Root-integrated toolkit for multivariate data analysis       *
 * Package: TMVA                                                                  *
 * Class  : TMVA_PDF                                                              *
 *                                                                                *
 * Description:                                                                   *
 *      PDF wrapper for histograms; uses user-definedspline interpolation         *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Andreas Hoecker <Andreas.Hocker@cern.ch> - CERN, Switzerland              *
 *      Xavier Prudent  <prudent@lapp.in2p3.fr>  - LAPP, France                   *
 *      Helge Voss      <Helge.Voss@cern.ch>     - MPI-KP Heidelberg, Germany     *
 *      Kai Voss        <Kai.Voss@cern.ch>       - U. of Victoria, Canada         *
 *                                                                                *
 * Copyright (c) 2005:                                                            *
 *      CERN, Switzerland,                                                        * 
 *      U. of Victoria, Canada,                                                   * 
 *      MPI-KP Heidelberg, Germany,                                               * 
 *      LAPP, Annecy, France                                                      *
 *                                                                                *
 * Redistribution and use in source and binary forms, with or without             *
 * modification, are permitted according to the terms listed in LICENSE           *
 * (http://mva.sourceforge.net/license.txt)                                       *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: TMVA_PDF.h,v 1.2 2006/03/14 19:52:53 kaivoss Exp $                   *
 **********************************************************************************/

#ifndef TMVA_PDF__H
#define TMVA_PDF__H

#include "TSpline.h"
#include "TH1.h"
#include "TGraph.h"
#include "TObject.h"

class TMVA_PDF : public TObject {
  
 public:

  enum SmoothMethod { Spline1, Spline2, Spline3, Spline5 };
  
  TMVA_PDF( const TH1* theHist, 
	   TMVA_PDF::SmoothMethod method = Spline2,
	   Int_t nsmooth = 0 );
  
  ~TMVA_PDF( void );
  
  Double_t GetVal( const Double_t x );

  TH1*     GetPDFHist ( void ){ return m_PDFHist; }
  Double_t GetIntegral( Double_t xmin, Double_t xmax );

  // accessors
  TSpline* GetSpline( void ) const { return m_spline; }
  Double_t GetXmin  ( void ) const { return m_xmin;   }
  Double_t GetXmax  ( void ) const { return m_xmax;   }

 private:

  void     checkHist(void);
  void     fillSplineToHist( void );
  Double_t Integral  ( Double_t xmin, Double_t xmax );
  Double_t Integral  ( void );
  
  Int_t      m_nbinsPDFHist;

  Int_t      m_nsmooth; // # times the histogram is smoothed
  Double_t   m_xmin, m_xmax;
  Int_t      m_nbins;

  TSpline*   m_spline;
  TH1*       m_PDFHist;
  TH1*       m_hist; // copy of input histogram
  TGraph*    m_graph;
  Double_t   m_integral;

  ClassDef(TMVA_PDF,0)  
};

#endif 
