/**********************************************************************************
 * Project: TMVA - a Root-integrated toolkit for multivariate data analysis       *
 * Package: TMVA                                                                  *
 * Class  : TMVA_Tools                                                            *
 *                                                                                *
 * Description:                                                                   *
 *      Static class with auxiliary applications and data treatment routines      *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Andreas Hoecker <Andreas.Hocker@cern.ch> - CERN, Switzerland              *
 *      Xavier Prudent  <prudent@lapp.in2p3.fr>  - LAPP, France                   *
 *      Helge Voss      <Helge.Voss@cern.ch>     - MPI-KP Heidelberg, Germany     *
 *      Kai Voss        <Kai.Voss@cern.ch>       - U. of Victoria, Canada         *
 *                                                                                *
 * Copyright (c) 2005:                                                            *
 *      CERN, Switzerland,                                                        * 
 *      U. of Victoria, Canada,                                                   * 
 *      MPI-KP Heidelberg, Germany,                                               * 
 *      LAPP, Annecy, France                                                      *
 *                                                                                *
 * Redistribution and use in source and binary forms, with or without             *
 * modification, are permitted according to the terms listed in LICENSE           *
 * (http://mva.sourceforge.net/license.txt)                                       *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: TMVA_Tools.h,v 1.3 2006/04/05 07:01:48 andreas.hoecker Exp $        
 **********************************************************************************/

#ifndef TMVA_Tools_H 
#define TMVA_Tools_H 1

#include <vector>
#include <string>

#include "TTree.h"
#include "TString.h"
#include "TH1.h"
#include "TTree.h"
#include "TList.h"
#include "TMatrixDBase.h"
#include "TMatrixD.h"
#include "TMatrixDSym.h"
#include "TMatrixDSymEigen.h"
#include "TH1.h"
#include "TSpline.h"

#include "TMVA_Event.h"

#define __N__(a1,a2,a3) TMVA_Tools::NormVariable(a1,a2,a3)

using std::vector;


namespace TMVA_Tools {

  //  TString GetName( void ) { return "TMVA_Tools"; }

  // simple statistics operations on tree entries
  void  ComputeStat( TTree* theTree, TString theVarName,
		     Double_t&, Double_t&, Double_t&, 
		     Double_t&, Double_t&, Double_t&, Bool_t norm = kFALSE );
  
  // simple statistics operations on Events in a Vector collection class 
  void  ComputeStat( std::vector<TMVA_Event*>, Int_t ivar,
		     Double_t&, Double_t&, Double_t&, 
		     Double_t&, Double_t&, Double_t&, Bool_t norm = kFALSE );
  


  // creates histograms normalized to one
  TH1* projNormTH1F( TTree* theTree, TString theVarName,
		     TString name, Int_t nbins, 
		     Double_t xmin, Double_t xmax, TString cut );

  // normalize histogram by its integral
  Double_t NormHist( TH1* theHist, Double_t norm = 1.0 );

  // parser for TString phrase with items separated by ':'
  TList* ParseFormatLine( TString theString );

  // returns covariance matrix for all variables in tree
  void GetCovarianceMatrix( TTree* theTree, TMatrixDBase *theMatrix, 
			    vector<TString>* theVars, Int_t theType, Bool_t norm = kFALSE );

  // returns correlation matrix for all variables in tree
  void GetCorrelationMatrix( TTree* theTree, TMatrixDBase *theMatrix, 
			     vector<TString>* theVars, Int_t theType );

  // returns the square-root of a symmetric matrix: symMat = sqrtMat*sqrtMat
  void GetSQRootMatrix( TMatrixDSym* symMat, TMatrixD* sqrtMat );

  // type-safe accessor to TTree elements
  Double_t GetValue( TTree *theTree, Int_t entry, TString varname );

  // check spline quality by comparison with initial histogram
  Bool_t CheckSplines( TH1*, TSpline* );

  // normalization of variable output
  Double_t NormVariable( Double_t x, Double_t xmin, Double_t xmax );


}

#endif // TMVA_Tools_H

